# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# Suspect that upstream prefers single-decimal versions
%global cpan_version 3.75
%global rpm_version 3.7.5

# This arch-specific package has no binaries and generates no debuginfo
%global debug_package %{nil}

Name:		perl-common-sense
Summary:	"Common sense" Perl defaults
Version:	%{rpm_version}
Release:	14.%{__distinit}%{__distvers}
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/common-sense
Source0:	https://cpan.metacpan.org/authors/id/M/ML/MLEHMANN/common-sense-%{cpan_version}.tar.gz
Patch1:		common-sense-3.71-podenc.patch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(feature)
BuildRequires:	perl(strict)
BuildRequires:	perl(utf8)
BuildRequires:	perl(warnings)
BuildRequires:	/usr/bin/pod2man
BuildRequires:	/usr/bin/pod2text
# Module Runtime
# (no additional dependencies)
# Test Suite
# (no additional dependencies)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

%description
This module implements some sane defaults for Perl programs, as defined
by two typical (or not so typical - use your common sense) specimens of
Perl coders:

It's supposed to be mostly the same, with much lower memory usage, as:

	use utf8;
	use strict qw(vars subs);
	use feature qw(say state switch);
	use feature qw(unicode_strings unicode_eval current_sub fc evalbytes);
	no feature qw(array_base);
	no warnings;
	use warnings qw(FATAL closed threads internal debugging pack
			prototype inplace io pipe unpack malloc
			deprecated glob digit printf layer
			reserved taint closure semicolon);
	no warnings qw(exec newline unopened);

%prep
%setup -q -n common-sense-%{cpan_version}

# Specify POD encoding
%patch -P 1

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

# Have a non-empty manpage
pod2man sense.pod > %{buildroot}%{_mandir}/man3/common::sense.3pm

%check
make test

%files
%license LICENSE
%doc Changes README t/
%dir %{perl_vendorarch}/common/
%{perl_vendorarch}/common/sense.pm
%doc %{perl_vendorarch}/common/sense.pod
%{_mandir}/man3/common::sense.3*

%changelog
* Wed Aug  9 2023 Paul Howarth <paul@city-fan.org> - 3.7.5-14
- Fix FTBFS due to %%rpmversion macro being built-in in rpm-4.18.92

* Tue Jul 11 2023 Paul Howarth <paul@city-fan.org> - 3.7.5-13
- Perl 5.38 rebuild

* Thu May  4 2023 Paul Howarth <paul@city-fan.org> - 3.7.5-12
- Use SPDX-format license tag
- Avoid use of deprecated patch syntax

* Tue May 31 2022 Paul Howarth <paul@city-fan.org> - 3.7.5-9
- Perl 5.36 rebuild

* Fri May 21 2021 Paul Howarth <paul@city-fan.org> - 3.7.5-6
- Perl 5.34 rebuild

* Wed Jun 24 2020 Paul Howarth <paul@city-fan.org> - 3.7.5-2
- Perl 5.32 rebuild

* Thu Apr  2 2020 Paul Howarth <paul@city-fan.org> - 3.7.5-1
- Update to 3.75
  - Make build (more) reproducible
  - Removed "portable" from the warnings list, as 32-bit perls (as opposed to
    32-bit platforms) are practically extinct and it warns about a weird subset
    of operations, e.g. 64-bit hex() is not ok, 64-bit addition is fine, makes
    no sense; additionally, other than hex/oct etc. harassment, there is
    nothing in this category that otherwise could be useful

* Fri May 31 2019 Paul Howarth <paul@city-fan.org> - 3.7.4-12
- Perl 5.30 rebuild

* Wed Jun 27 2018 Paul Howarth <paul@city-fan.org> - 3.7.4-9
- Perl 5.28 rebuild

* Fri Aug  4 2017 Paul Howarth <paul@city-fan.org> - 3.7.4-7
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - BR: perl(feature) unconditionally

* Tue Aug  9 2016 Paul Howarth <paul@city-fan.org> - 3.7.4-3
- Classify buildreqs by usage
- Simplify find command using -delete

* Mon Jun 29 2015 Paul Howarth <paul@city-fan.org> - 3.7.4-1
- Update to 3.74
  - The generated README file was empty
- Use %%license where possible

* Thu Jun 12 2014 Paul Howarth <paul@city-fan.org> - 3.7.3-1
- Update to 3.73
  - Remove "deprecated", as it turned out to be yet another time bomb as p5p
    don't care the least about backwards compatibility anymore
    (https://rt.perl.org/Public/Bug/Display.html?id=119123)
  - Switching paths once more as this turned out to be a doc bug in EU::MM;
    this should not affect anything though
- Drop %%defattr, redundant since rpm 4.4

* Wed Jul 31 2013 Paul Howarth <paul@city-fan.org> - 3.7.2-1
- Update to 3.72
  - Fix install paths
- Manually generate the manpage so we get a non-empty one

* Wed Jul 31 2013 Paul Howarth <paul@city-fan.org> - 3.7.1-1
- Update to 3.71
  - Move pod to separate file, to further improve loading times
  - Make it arch-specific, adding a test that warns when an old version is
    still installed
  - Due to a logic glitch, warnings were not enabled at all on 5.16
  - CPAN failed to parse the version number in 3.7, try to work around
- Add patch to get files installed to sane places
- Re-create non-empty README file
- Avoid creation of empty debuginfo package for this now-arch-specific package

* Fri Jun 22 2012 Paul Howarth <paul@city-fan.org> - 3.6-2
- Perl 5.16 rebuild

* Sun Jun 17 2012 Paul Howarth <paul@city-fan.org> - 3.6-1
- Update to 3.6:
  - Work around more 5.16 breakage - $^H doesn't work as nicely as P5P make
    you believe
  - Add features: unicode_strings current_sub fc evalbytes
  - Disable features: array_base

* Sat Mar 24 2012 Paul Howarth <paul@city-fan.org> - 3.5-1
- Update to 3.5:
  - Localise $^W, as this causes warnings with 5.16 when some lost soul uses
    -w; common::sense doesn't support $^W, but tries to shield module authors
    and programs from its ill effects
- Obsolete/provide old -tests subpackage from Fedora
- Don't need to remove empty directories from buildroot
- Drop support for distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Thu Jun 23 2011 Paul Howarth <paul@city-fan.org> - 3.4-2
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Fri Jan 21 2011 Paul Howarth <paul@city-fan.org> - 3.4-1
- Import from Fedora
- Update to 3.4:
  - Remove "regexp" category
  - Use META.json instead of META.yml

* Sat Dec 18 2010 Iain Arnell <iarnell@gmail.com> - 3.3-1
- Update to latest upstream version
- Clean up spec for modern rpmbuild

* Wed Dec 15 2010 Marcela Maslanova <mmaslano@redhat.com> - 3.0-3
- Rebuild to fix problems with vendorarch/lib (#661697)

* Fri Apr 30 2010 Marcela Maslanova <mmaslano@redhat.com> - 3.0-2
- Mass rebuild with perl 5.12.0

* Sun Mar 14 2010 Chris Weyl <cweyl@alumni.drew.edu> - 3.0-1
- Update by Fedora::App::MaintainerTools 0.006
- PERL_INSTALL_ROOT => DESTDIR
- Updating to latest GA CPAN version (3.0)

* Fri Dec  4 2009 Stepan Kasal <skasal@redhat.com> - 1.0-3
- Rebuild against perl 5.10.1

* Sun Sep 27 2009 Chris Weyl <cweyl@alumni.drew.edu> - 1.0-2
- Update summary (though now we deviate from upstream)

* Mon Aug 31 2009 Chris Weyl <cweyl@alumni.drew.edu> - 1.0-1
- Auto-update to 1.0 (by cpan-spec-update 0.01)

* Fri Aug 21 2009 Chris Weyl <cweyl@alumni.drew.edu> - 0.04-0
- Initial RPM packaging
- Generated with cpan2dist (CPANPLUS::Dist::RPM version 0.0.8)
